package com.example.rehabilitation.fragment.User

import android.os.Bundle
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.lifecycle.ViewModelProvider
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.rehabilitation.Baza.TaskItem
import com.example.rehabilitation.Baza.TaskItemAdapter
import com.example.rehabilitation.Baza.TaskItemClickListener
import com.example.rehabilitation.Baza.TaskViewModel
import com.example.rehabilitation.databinding.FragmentSceduleBinding


class SceduleFragment(var taskItem: TaskItem?) : Fragment(), TaskItemClickListener {
    private lateinit var binding: FragmentSceduleBinding
    private lateinit var taskViewModel: TaskViewModel

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        binding = FragmentSceduleBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        //Закрытие карточки определенного дня
        binding.btnExitCardSport.setOnClickListener {
            binding.CLCardSport.visibility = View.GONE
            binding.CLListSport.visibility = View.VISIBLE
            binding.txtNameCard.setText("")
            binding.txtDescCard.setText("")
        }

        if(taskItem != null){
            binding.CLCardSport.visibility = View.VISIBLE
            binding.CLListSport.visibility = View.GONE
            binding.txtNameCard.text = taskItem!!.name
            binding.txtDescCard.text = taskItem!!.desc
        }
        else{
            binding.CLCardSport.visibility = View.GONE
            binding.CLListSport.visibility = View.VISIBLE
        }

        taskViewModel = ViewModelProvider(requireActivity()).get(TaskViewModel::class.java)
        binding.btnSave.setOnClickListener {
            saveAction()
        }

        setRecycleView()

    }

    private fun setRecycleView() {
        taskViewModel.taskItems.observe(requireActivity()){
            binding.todoListRecycleView.apply {
                layoutManager = LinearLayoutManager(activity?.applicationContext)
                adapter = TaskItemAdapter(it,this@SceduleFragment)
            }
        }
    }

    private fun saveAction() {
        val name = binding.edName.text.toString()
        val desc = binding.edDesc.text.toString()

        if(taskItem == null){
            val newTask = TaskItem(name,desc,null,null)
            taskViewModel.addTaskItem(newTask)
        }
        else{
            taskViewModel.updateTaskItem(taskItem!!.id,name,desc,null)
        }
        binding.edName.setText("")
        binding.edDesc.setText("")
    }

    override fun onResume() {
        super.onResume()

    }

    override fun onDestroy() {
        super.onDestroy()

    }

    companion object {
        fun newInstance() = SceduleFragment(null)
    }

    override fun editTaskItem(taskitem: TaskItem) {
        binding.CLCardSport.visibility = View.VISIBLE
        binding.CLListSport.visibility = View.GONE

        binding.txtNameCard.setText(taskitem.name)
        binding.txtDescCard.setText(taskitem.desc)
    }

    override fun completeTaskItem(taskitem: TaskItem) {
        taskItem?.let { taskViewModel.setCompleted(it) }
    }
}